import { InjectionToken, Injectable, Inject, RendererFactory2, NgModule, defineInjectable, inject } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { BehaviorSubject } from 'rxjs';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const NgGoogleMapsLoaderConfig = new InjectionToken('ng google maps loader config');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/** @enum {number} */
const LoadStatus = { NotLoaded: 0, Loading: 1, Loaded: 2, };
LoadStatus[LoadStatus.NotLoaded] = "NotLoaded";
LoadStatus[LoadStatus.Loading] = "Loading";
LoadStatus[LoadStatus.Loaded] = "Loaded";
class NgGoogleMapsLoaderService {
    /**
     * @param {?} document
     * @param {?} ngGoogleMapsLoaderConfig
     * @param {?} rendererFactory
     */
    constructor(document, ngGoogleMapsLoaderConfig, rendererFactory) {
        this.document = document;
        this.ngGoogleMapsLoaderConfig = ngGoogleMapsLoaderConfig;
        this._loadStatusSubject = new BehaviorSubject(LoadStatus.NotLoaded);
        this._loadScriptId = 'ng-google-maps-loader-script-id';
        this._renderer2 = rendererFactory.createRenderer(null, null);
    }
    /**
     * @return {?}
     */
    get loadScipt() {
        return this._loadScript;
    }
    /**
     * @return {?}
     */
    get loadSciptId() {
        return this._loadScriptId;
    }
    /**
     * @return {?}
     */
    get loadStatus() {
        return /** @type {?} */ (this._loadStatusSubject);
    }
    /**
     * @return {?}
     */
    load() {
        if (this.document.getElementById(this._loadScriptId)) {
            return;
        }
        this._loadStatusSubject.next(LoadStatus.Loading);
        const /** @type {?} */ googleMapsApiUrl = this.createGoogleMapsApiUrl();
        this._loadScript = this.createLoadScript(googleMapsApiUrl);
        this._renderer2.appendChild(this.document.body, this._loadScript);
    }
    /**
     * @return {?}
     */
    createGoogleMapsApiUrl() {
        return [
            'https://maps.googleapis.com/maps/api/js',
            `?key=${this.ngGoogleMapsLoaderConfig.key}`,
            `&libraries=${this.ngGoogleMapsLoaderConfig.libraries.join(',')}`,
            `&language=${this.ngGoogleMapsLoaderConfig.language || 'en'}`,
        ].join('');
    }
    /**
     * @param {?} googleMapsApiUrl
     * @return {?}
     */
    createLoadScript(googleMapsApiUrl) {
        const /** @type {?} */ script = this._renderer2.createElement('script');
        script.setAttribute('defer', '');
        script.setAttribute('async', '');
        script.type = 'text/javascript';
        script.id = this._loadScriptId;
        script.src = googleMapsApiUrl;
        script.onload = this.scriptOnLoad.bind(this);
        return script;
    }
    /**
     * @return {?}
     */
    scriptOnLoad() {
        this._loadStatusSubject.next(LoadStatus.Loaded);
        this._loadStatusSubject.complete();
    }
}
NgGoogleMapsLoaderService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] },
];
/** @nocollapse */
NgGoogleMapsLoaderService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    { type: NgGoogleMapsLoaderConfig, decorators: [{ type: Inject, args: [NgGoogleMapsLoaderConfig,] },] },
    { type: RendererFactory2, },
];
/** @nocollapse */ NgGoogleMapsLoaderService.ngInjectableDef = defineInjectable({ factory: function NgGoogleMapsLoaderService_Factory() { return new NgGoogleMapsLoaderService(inject(DOCUMENT), inject(NgGoogleMapsLoaderConfig), inject(RendererFactory2)); }, token: NgGoogleMapsLoaderService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgGoogleMapsLoaderModule {
    /**
     * @param {?} ngGoogleMapsLoaderConfig
     * @return {?}
     */
    static forRoot(ngGoogleMapsLoaderConfig) {
        return {
            ngModule: NgGoogleMapsLoaderModule,
            providers: [
                {
                    provide: NgGoogleMapsLoaderConfig,
                    useValue: ngGoogleMapsLoaderConfig,
                },
                NgGoogleMapsLoaderService,
            ]
        };
    }
}
NgGoogleMapsLoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [],
                exports: []
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/*
 * Public API Surface of ng-google-maps-loader
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { LoadStatus, NgGoogleMapsLoaderService, NgGoogleMapsLoaderModule, NgGoogleMapsLoaderConfig as ɵa };
//# sourceMappingURL=ng-google-maps-loader.js.map
