import { InjectionToken, Injectable, Inject, RendererFactory2, NgModule, defineInjectable, inject } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { BehaviorSubject } from 'rxjs';

var NgGoogleMapsLoaderConfig = new InjectionToken('ng google maps loader config');
var LoadStatus = { NotLoaded: 0, Loading: 1, Loaded: 2, };
LoadStatus[LoadStatus.NotLoaded] = "NotLoaded";
LoadStatus[LoadStatus.Loading] = "Loading";
LoadStatus[LoadStatus.Loaded] = "Loaded";
var NgGoogleMapsLoaderService = /** @class */ (function () {
    function NgGoogleMapsLoaderService(document, ngGoogleMapsLoaderConfig, rendererFactory) {
        this.document = document;
        this.ngGoogleMapsLoaderConfig = ngGoogleMapsLoaderConfig;
        this._loadStatusSubject = new BehaviorSubject(LoadStatus.NotLoaded);
        this._loadScriptId = 'ng-google-maps-loader-script-id';
        this._renderer2 = rendererFactory.createRenderer(null, null);
    }
    Object.defineProperty(NgGoogleMapsLoaderService.prototype, "loadScipt", {
        get: function () {
            return this._loadScript;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgGoogleMapsLoaderService.prototype, "loadSciptId", {
        get: function () {
            return this._loadScriptId;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgGoogleMapsLoaderService.prototype, "loadStatus", {
        get: function () {
            return (this._loadStatusSubject);
        },
        enumerable: true,
        configurable: true
    });
    NgGoogleMapsLoaderService.prototype.load = function () {
        if (this.document.getElementById(this._loadScriptId)) {
            return;
        }
        this._loadStatusSubject.next(LoadStatus.Loading);
        var googleMapsApiUrl = this.createGoogleMapsApiUrl();
        this._loadScript = this.createLoadScript(googleMapsApiUrl);
        this._renderer2.appendChild(this.document.body, this._loadScript);
    };
    NgGoogleMapsLoaderService.prototype.createGoogleMapsApiUrl = function () {
        return [
            'https://maps.googleapis.com/maps/api/js',
            "?key=" + this.ngGoogleMapsLoaderConfig.key,
            "&libraries=" + this.ngGoogleMapsLoaderConfig.libraries.join(','),
            "&language=" + (this.ngGoogleMapsLoaderConfig.language || 'en'),
        ].join('');
    };
    NgGoogleMapsLoaderService.prototype.createLoadScript = function (googleMapsApiUrl) {
        var script = this._renderer2.createElement('script');
        script.setAttribute('defer', '');
        script.setAttribute('async', '');
        script.type = 'text/javascript';
        script.id = this._loadScriptId;
        script.src = googleMapsApiUrl;
        script.onload = this.scriptOnLoad.bind(this);
        return script;
    };
    NgGoogleMapsLoaderService.prototype.scriptOnLoad = function () {
        this._loadStatusSubject.next(LoadStatus.Loaded);
        this._loadStatusSubject.complete();
    };
    return NgGoogleMapsLoaderService;
}());
NgGoogleMapsLoaderService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] },
];
NgGoogleMapsLoaderService.ctorParameters = function () { return [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    { type: NgGoogleMapsLoaderConfig, decorators: [{ type: Inject, args: [NgGoogleMapsLoaderConfig,] },] },
    { type: RendererFactory2, },
]; };
NgGoogleMapsLoaderService.ngInjectableDef = defineInjectable({ factory: function NgGoogleMapsLoaderService_Factory() { return new NgGoogleMapsLoaderService(inject(DOCUMENT), inject(NgGoogleMapsLoaderConfig), inject(RendererFactory2)); }, token: NgGoogleMapsLoaderService, providedIn: "root" });
var NgGoogleMapsLoaderModule = /** @class */ (function () {
    function NgGoogleMapsLoaderModule() {
    }
    NgGoogleMapsLoaderModule.forRoot = function (ngGoogleMapsLoaderConfig) {
        return {
            ngModule: NgGoogleMapsLoaderModule,
            providers: [
                {
                    provide: NgGoogleMapsLoaderConfig,
                    useValue: ngGoogleMapsLoaderConfig,
                },
                NgGoogleMapsLoaderService,
            ]
        };
    };
    return NgGoogleMapsLoaderModule;
}());
NgGoogleMapsLoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [],
                exports: []
            },] },
];

export { LoadStatus, NgGoogleMapsLoaderService, NgGoogleMapsLoaderModule, NgGoogleMapsLoaderConfig as ɵa };
//# sourceMappingURL=ng-google-maps-loader.js.map
